@@ -8,12 +8,7 @@ setMethod("asJSON", "character",
 	function(x, container = TRUE, collapse = "\n", digits = 5, ...) {
 		
 		tmp <- x
-		tmp = gsub('\\', '\\\\', tmp, fixed=T);
-		tmp = gsub("\"", "\\\"", tmp, fixed=T);
-		tmp = gsub("\n", "\\n", tmp, fixed=T);
-		tmp = gsub("\r", "\\r", tmp, fixed=T);
-		tmp = gsub("\t", "\\t", tmp, fixed=T);
-		tmp = gsub("\a", "\\a", tmp, fixed=T);
+		tmp <- json.escape(tmp);
 		
 		tmp = dQuote(tmp);
 		
