@@ -4,8 +4,8 @@
 ###############################################################################
 
 
-setMethod("toJSON", "numeric",
-	function(x, container = TRUE, collapse = "\n", digits = 5, NA_encode = TRUE, ..., .level = 1L, .withNames=F) {
+setMethod("asJSON", "numeric",
+	function(x, container = TRUE, collapse = "\n", digits = 5, NA_encode = TRUE, ...) {
 		tmp = trim(formatC(x, digits = digits));
 		
 		if(any(missings <- !is.finite(x))){
